# Verint WFO OMNI Statistics Service

---

## The reason

Verint WFO OMNI Statistics Service is responsible for creating various text related 
statistics in appropriate Verint format. For general WFO text statistics (like chats 
grouped by skills or emails grouped by campaigns) Verint CSI format is used. For 
details on CSI format see WFO\_V15\_2\_WFM_Generic_Interfaces_Adapters.pdf version 15.2 
or higher. For agent's text score cards Verint SMIA format is used. For details on 
SMIA format see WFO\_V15\_2\_Scorecards_Adapter.pdf version 15.2 or higher. DataLake Service 
is the main source of calculated data for all supported types of statistic. 

## Connectivity requirements

Should have:

1. Read access to Main and Customer DB
1. Access to Cloud Token Provider Service
1. Access to Cloud DataLake Subscription API Service
1. Subscriber level access to PubSub Service of Five9 jurisdiction level
1. Access to Cloud Avro Scheme Registry Service
1. Access to Verint-proxy hosts configured in the system

## Software requirements

1. CentOS &gt;= 7.x
1. Java JRE &gt;= 1.8

## Installation

1. Download respective RPM file verint-wfo-omni-stats-&lt;version&gt;.noarch.rpm
1. Install downloaded RPM file.  
   By default application will be installed to /opt/verint-wfo-omni-stats  
   ***rpm [--prefix=&lt;installation directory&gt;] -&lt;i|U&gt;vh &lt;downloaded rpm file&gt;***
1. Basically you can install and run any number of nodes to serve the same set of 
   providers but 2 or 3 is pretty fair

## Start/Stop

Use  
***service verint-wfo-omni-stats &lt;stop|start|restart|status&gt;***   
command to start the service

## Service configuration

After installation you will have file structure:   
verint-scorecard-app  
| -- config  
|     | -- application.yml  
|     | -- jmxremote.access  
|     | -- jmxremote.password  
|     | -- log4j2.xml  
|     | -- queries.xml  
|     | -- subscription-deliveries.properties  
|     | -- verint-proxy-address-templates.properties  
| -- doc  
|     | -- README.md  
| -- verint-wfo-omni-stats  
| -- verint-wfo-omni-stats.conf  

### ./config/application.yml. 

#### dbConf 

There you should specify Main DB Read Only connection settings

#### providers

List of all provider Ids the service should work with

#### avroSchemeRegistryConf

The main reference is [datalake-serde library](https://gitlab.com/fivn/datalake/core/datalake-serde)

1. *schema.registry.url* is where Schema Registry Service is available
1. *schema.registry.client.auth.url* is a base URL for Token Provider Service
1. *schema.registry.client.auth.client.id* is a client Id to get token from  
   Token Provider Service
1. *schema.registry.client.auth.client.secret* is a secret to get token from  
   Token Provider Service

#### pubsubConf

1. *serviceAccountKeyFilePath* is a path to GCP service account file

#### apigeeConf

1. *ownerId* is an owner Id configured to use with Apigee
1. *cloudServiceType* is a service type configured to use with Apigee

#### taskProccesingConf

1. *checkForTaskTimeout* is how often we should check for SAT settings changes  
   Specified using ISO-8601

#### reportProccesingConf

1. *reportHandleTimeout* is how much time we have to handle a single work force report 
   we got from DataLake  
   Specified using ISO-8601
1. *noReportTimeout* is how long to wait to log absent work force reports

#### wfoServicesConf

1. *subscriptionServiceBasePath* is a path to DataLake services which will be concatenated 
   with configured cloud service base URL in SAT per domain

#### verintProxyConf

1. *connectTimeout* is a timeout to connect with Verint-Proxy  
   Specified using ISO-8601
1. *readTimeout* is connection read timeout  
   Specified using ISO-8601  
    
   
### ./config/verint-proxy-address-templates.properties
   
Contains Verint-proxy URL templates for all supported statistic types.

### ./config/subscription-deliveries.properties

Contains PubSub topic names along with corresponding subscription names for all supported statistic types.  
All those PubSub topics and subscriptions should be created in advance.

### ./verint-wfo-omni-stats.conf

*five9.crypto.customer.vault.masterKeyDirs* is where you have to place master keys for domains to decrypt cloud environment client secrets stored in Main DB


## SAT Settings

You can enable/disable various statistics type on Domain/Verint WFO page

1. Scorecards for Email
1. Scorecards for Chat
1. Inbound Stats (CSI) for Email by Skill
1. Inbound Stats (CSI) for Email by Campaign
1. Inbound Stats (CSI) for Chat by Skill
1. Inbound Stats (CSI) for Chat by Campaign


*Verint Code* and *Time Zone* are required